@@ -45,15 +45,15 @@
 #include <QClipboard>
 
 #include <KLineEdit>
-#include <kcombobox.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <kcmultidialog.h>
+#include <KComboBox>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KCMultiDialog>
 #include <QDialogButtonBox>
 #include <kldap/ldapobject.h>
 #include <kldap/ldapserver.h>
 #include <QLineEdit>
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 #include <QLocale>
 #include <KLocalizedString>
@@ -483,7 +483,7 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     : QDialog(parent)
     , d(new Private(this))
 {
-    setWindowTitle(i18n("Import Contacts from LDAP"));
+    setWindowTitle(i18nc("@title:window", "Import Contacts from LDAP"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel, this);
@@ -613,7 +613,9 @@ LdapSearchDialog::LdapSearchDialog(QWidget *parent)
     user2Button->setText(i18n("Configure LDAP Servers..."));
 
     connect(d->mRecursiveCheckbox, &QCheckBox::toggled,
-            this, [this](bool state) { d->slotSetScope(state); });
+            this, [this](bool state) {
+        d->slotSetScope(state);
+    });
     connect(d->mSearchButton, SIGNAL(clicked()),
             this, SLOT(slotStartSearch()));
 
@@ -699,7 +701,9 @@ void LdapSearchDialog::Private::restoreSettings()
 
             q->connect(ldapClient, SIGNAL(result(KLDAP::LdapClient,KLDAP::LdapObject)), q, SLOT(slotAddResult(KLDAP::LdapClient,KLDAP::LdapObject)));
             q->connect(ldapClient, SIGNAL(done()), q, SLOT(slotSearchDone()));
-            q->connect(ldapClient, &LdapClient::error, q, [this](const QString &err) {slotError(err);});
+            q->connect(ldapClient, &LdapClient::error, q, [this](const QString &err) {
+                slotError(err);
+            });
 
             mLdapClientList.append(ldapClient);
         }
@@ -877,7 +881,7 @@ void LdapSearchDialog::slotUser2()
     // Configure LDAP servers
 
     QPointer<KCMultiDialog> dialog = new KCMultiDialog(this);
-    dialog->setWindowTitle(i18n("Configure the Address Book LDAP Settings"));
+    dialog->setWindowTitle(i18nc("@title:window", "Configure the Address Book LDAP Settings"));
     dialog->addModule(QStringLiteral("kcmldap.desktop"));
 
     if (dialog->exec()) {   //krazy:exclude=crashy
