@@ -650,7 +650,7 @@ void AddresseeLineEdit::loadContacts()
         for (; it != end; ++it) {
             KEmailAddress::extractEmailAddressAndName(*it, email, name);
             name = KEmailAddress::quoteNameIfNecessary(name);
-            if ((name[0] == QLatin1Char('"')) && (name[name.length() - 1] == QLatin1Char('"'))) {
+            if (!name.isEmpty() && (name[0] == QLatin1Char('"')) && (name[name.length() - 1] == QLatin1Char('"'))) {
                 name.remove(0, 1);
                 name.chop(1);
             }
