@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -20,7 +20,7 @@
 
 #include "completionorderwidget.h"
 
-#include <kdescendantsproxymodel.h>
+#include <KDescendantsProxyModel>
 #include "Libkdepim/LdapClient"
 #include "ldap/ldapclientsearch.h"
 #include "ldap/ldapclientsearchconfig.h"
@@ -345,7 +345,8 @@ void CompletionOrderWidget::loadCompletionItems()
 {
     if (mLdapSearch) {
         // The first step is to gather all the data, creating CompletionItem objects
-        for (KLDAP::LdapClient *client : mLdapSearch->clients()) {
+        const QList<KLDAP::LdapClient *> listClients = mLdapSearch->clients();
+        for (KLDAP::LdapClient *client : listClients) {
             new CompletionViewItem(mListView, new LDAPCompletionItem(client));
         }
     }
