@@ -87,11 +87,13 @@ public:
             address.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailPreferedFormatting"), mShowAsHTML ? QStringLiteral("HTML") : QStringLiteral("TEXT"));
             address.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailAllowToRemoteContent"), mRemoteContent ? QStringLiteral("TRUE") : QStringLiteral("FALSE"));
             item.setPayload<KContacts::Addressee>(address);
-            Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(item);
-            q->connect(job, &Akonadi::ItemModifyJob::result, q, [this](KJob *job) {
-                Akonadi::ItemModifyJob *modifiedJob = static_cast<Akonadi::ItemModifyJob *>(job);
-                Q_EMIT q->contactUpdated(modifiedJob->item(), messageId);
-                slotAddModifyContactDone(job);
+            Akonadi::ItemModifyJob *itemModifyJob = new Akonadi::ItemModifyJob(item);
+            q->connect(itemModifyJob, &Akonadi::ItemModifyJob::result, q, [this](KJob *itemModifyJob) {
+                Akonadi::ItemModifyJob *modifiedJob = static_cast<Akonadi::ItemModifyJob *>(itemModifyJob);
+                if (!modifiedJob->error()) {
+                    Q_EMIT q->contactUpdated(modifiedJob->item(), messageId, mShowAsHTML, mRemoteContent);
+                }
+                slotAddModifyContactDone(itemModifyJob);
             });
         } else {
             searchContact();
@@ -118,11 +120,13 @@ public:
             contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailPreferedFormatting"), mShowAsHTML ? QStringLiteral("HTML") : QStringLiteral("TEXT"));
             contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailAllowToRemoteContent"), mRemoteContent ? QStringLiteral("TRUE") : QStringLiteral("FALSE"));
             item.setPayload<KContacts::Addressee>(contact);
-            Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(item);
-            q->connect(job, &Akonadi::ItemModifyJob::result, q, [this](KJob *job) {
-                Akonadi::ItemModifyJob *modifiedJob = static_cast<Akonadi::ItemModifyJob *>(job);
-                Q_EMIT q->contactUpdated(modifiedJob->item(), messageId);
-                slotAddModifyContactDone(job);
+            Akonadi::ItemModifyJob *itemModifyJob = new Akonadi::ItemModifyJob(item);
+            q->connect(itemModifyJob, &Akonadi::ItemModifyJob::result, q, [this](KJob *itemModifyJob) {
+                Akonadi::ItemModifyJob *modifiedJob = static_cast<Akonadi::ItemModifyJob *>(itemModifyJob);
+                if (!modifiedJob->error()) {
+                    Q_EMIT q->contactUpdated(modifiedJob->item(), messageId, mShowAsHTML, mRemoteContent);
+                }
+                slotAddModifyContactDone(itemModifyJob);
             });
         }
     }
@@ -243,10 +247,12 @@ public:
 
         // save the new item in akonadi storage
         Akonadi::ItemCreateJob *createJob = new Akonadi::ItemCreateJob(item, addressBook, q);
-        q->connect(createJob, &Akonadi::ItemCreateJob::result, q, [this](KJob *job) {
-            Akonadi::ItemCreateJob *modifiedJob = static_cast<Akonadi::ItemCreateJob *>(job);
-            Q_EMIT q->contactUpdated(modifiedJob->item(), messageId);
-            slotAddModifyContactDone(job);
+        q->connect(createJob, &Akonadi::ItemCreateJob::result, q, [this](KJob *createJob) {
+            Akonadi::ItemCreateJob *modifiedJob = static_cast<Akonadi::ItemCreateJob *>(createJob);
+            if (!modifiedJob->error()) {
+                Q_EMIT q->contactUpdated(modifiedJob->item(), messageId, mShowAsHTML, mRemoteContent);
+            }
+            slotAddModifyContactDone(createJob);
         });
     }
 
